/**
 * @file
 * Custom Paste Filters CKEditor plugin.
 *
 * Plugin to add some specific paste filters do CKEditor.
 */

 (function () {
  'use strict';

  // Function to apply the filters
  let apply_filter = {
    nbsp : function(data) {
      return data.replace(/\s/g,' ');
    },
    empty_paragraph : function(data) {
      var container = document.createElement('div');
      var html = '';

      container.insertAdjacentHTML('beforeend', data);
      var paragraphs = container.querySelectorAll('p');

      paragraphs.forEach(element => {
        if (element.innerText.trim() !== '') {
          html = html + element.outerHTML;
        }
      });

      return html;
    }
  };

  // Add the Custom Paste Filters plugin to CKEditor
  CKEDITOR.plugins.add('custompastefilters', {
    init : function( editor ) {
      var filterSettings = editor.config.customPasteFilters;

      if (filterSettings) {
        var nbsp_filter = filterSettings.nbsp_filter;
        var empty_paragraph_filter = filterSettings.empty_paragraph_filter;

        editor.on( 'paste', function(evt) {
          var ckeditor_data = evt.data.dataValue;

          if (nbsp_filter) {
            ckeditor_data = apply_filter.nbsp(ckeditor_data);
          }

          if (empty_paragraph_filter) {
            ckeditor_data = apply_filter.empty_paragraph(ckeditor_data);
          }

          evt.data.dataValue = ckeditor_data;
        });
      }
    }
  });
} ());
